from .. import Provider as AutomotiveProvider


class Provider(AutomotiveProvider):
    """Implement automotive provider for ``en_GB`` locale.

    Sources:

    - https://en.wikipedia.org/wiki/Vehicle_registration_plates_of_the_United_Kingdom
    """

    license_formats = (
        '??## ???',
        '??##???',
    )



from .. import Provider as CompanyProvider


class Provider(CompanyProvider):
    formats = (
        '{{last_name}} {{company_suffix}}',
        '{{last_name}} {{last_name}} {{company_suffix}}',
        '{{large_company}}',
    )
    # Source: https://www.capital.com.tr/listeler/capital-500
    large_companies = (
        'Tüpraş', 'Türk Hava Yolları', 'Petrol Ofisi', 'Opet', 'BİM', 'Ford Otosan', 'Arçelik', 'Vestel',
        'Toyota Otomotiv', 'Oyak Renault', 'A101 Yeni Mağzacılık', 'Turkcell', 'Türk Telekom', 'Anadolu Efes', 'Migros',
        'LC Waikiki', 'Peak Games', 'Masomo', 'EnerjiSA', 'Tofaş', 'Şişecam', 'Selçuk Ecza', 'ŞOK Marketler', 'Petkim',
        'Limak İnşaat', 'Aselsan', 'Havelsan', 'Roketsan', 'Şişecam',
    )
    company_suffixes = (
        'A.Ş.', 'Ltd.', 'Şti.',
    )

    def large_company(self):
        """
        :example: 'Peak Games'
        """
        return self.random_element(self.large_companies)



from string import ascii_uppercase

from ... import BaseProvider


class Provider(BaseProvider):
    """Implement automotive provider for ``en_PH`` locale.

    Vehicle registration in the Philippines has many controversies and is full
    of quirks. On top of that, some terms are highly subject to interpretation
    or to varying definitions when applied colloquially, e.g. "motor" usually
    refers to either a machine's motor or a motorcycle, "vehicles" usually means
    cars, SUVs, vans, and trucks but not motorcycles. Please read any additional
    notes of individual methods for more details.

    Sources:

    - https://en.wikipedia.org/wiki/Vehicle_registration_plates_of_the_Philippines
    """

    protocol_licenses = tuple(str(x) for x in range(1, 18) if x != 15)
    motorcycle_license_formats = (
        '??####',     # 1981 series
        '??#####',    # 2014 series
    )
    automobile_license_formats = (
        '???###',    # 1981 series
        '???####',   # 2014 series
    )
    license_formats = motorcycle_license_formats + automobile_license_formats

    def _license_plate(self, license_format):
        return self.bothify(self.random_element(license_format), ascii_uppercase)

    def protocol_license_plate(self):
        """Generate a protocol license plate.

        .. note::
           High ranking government officials are entitled to use low numbered
           protocol license plates.
        """
        return self.random_element(self.protocol_licenses)

    def motorcycle_license_plate(self):
        """Generate a motorcycle license plate.

        .. note::
           Motorcycles and any improvised vehicle with a motorcycle as its base
           are issued motorcycle license plates.
        """
        return self._license_plate(self.motorcycle_license_formats)

    def automobile_license_plate(self):
        """Generate an automobile license plate.

        .. note::
           Cars, SUVs, vans, trucks, and other 4-wheeled civilian vehicles are
           considered automobiles for this purpose.
        """
        return self._license_plate(self.automobile_license_formats)

    def license_plate(self):
        """Generate a license plate.

        .. note::
           This method will never generate protocol plates, because such plates
           are only for specific use cases.
        """
        return self._license_plate(self.license_formats)



import random
import re

from collections import OrderedDict

from faker.config import DEFAULT_LOCALE
from faker.factory import Factory
from faker.generator import Generator
from faker.utils.distribution import choices_distribution


class Faker:
    """Proxy class capable of supporting multiple locales"""

    cache_pattern = re.compile(r'^_cached_\w*_mapping$')
    generator_attrs = [
        attr for attr in dir(Generator)
        if not attr.startswith('__')
        and attr not in ['seed', 'seed_instance', 'random']
    ]

    def __init__(self, locale=None, providers=None,
                 generator=None, includes=None, **config):
        self._factory_map = OrderedDict()
        self._weights = None

        if isinstance(locale, str):
            locales = [locale.replace('-', '_')]

        # This guarantees a FIFO ordering of elements in `locales` based on the final
        # locale string while discarding duplicates after processing
        elif isinstance(locale, (list, tuple, set)):
            locales = []
            for code in locale:
                if not isinstance(code, str):
                    raise TypeError('The locale "%s" must be a string.' % str(code))
                final_locale = code.replace('-', '_')
                if final_locale not in locales:
                    locales.append(final_locale)

        elif isinstance(locale, OrderedDict):
            assert all(isinstance(v, (int, float)) for v in locale.values())
            odict = OrderedDict()
            for k, v in locale.items():
                key = k.replace('-', '_')
                odict[key] = v
            locales = list(odict.keys())
            self._weights = list(odict.values())

        else:
            locales = [DEFAULT_LOCALE]

        for locale in locales:
            self._factory_map[locale] = Factory.create(locale, providers, generator, includes, **config)

        self._locales = locales
        self._factories = list(self._factory_map.values())

    def __dir__(self):
        attributes = set(super(Faker, self).__dir__())
        for factory in self.factories:
            attributes |= {
                attr for attr in dir(factory) if not attr.startswith('_')
            }
        return sorted(attributes)

    def __getitem__(self, locale):
        return self._factory_map[locale.replace('-', '_')]

    def __getattribute__(self, attr):
        """
        Handles the "attribute resolution" behavior for declared members of this proxy class

        The class method `seed` cannot be called from an instance.

        :param attr: attribute name
        :return: the appropriate attribute
        """
        if attr == 'seed':
            msg = (
                'Calling `.seed()` on instances is deprecated. '
                'Use the class method `Faker.seed()` instead.'
            )
            raise TypeError(msg)
        else:
            return super().__getattribute__(attr)

    def __getattr__(self, attr):
        """
        Handles cache access and proxying behavior

        :param attr: attribute name
        :return: the appropriate attribute
        """

        if len(self._factories) == 1:
            return getattr(self._factories[0], attr)
        elif attr in self.generator_attrs:
            msg = 'Proxying calls to `%s` is not implemented in multiple locale mode.' % attr
            raise NotImplementedError(msg)
        elif self.cache_pattern.match(attr):
            msg = 'Cached attribute `%s` does not exist' % attr
            raise AttributeError(msg)
        else:
            factory = self._select_factory(attr)
            return getattr(factory, attr)

    def _select_factory(self, method_name):
        """
        Returns a random factory that supports the provider method

        :param method_name: Name of provider method
        :return: A factory that supports the provider method
        """

        factories, weights = self._map_provider_method(method_name)
        if len(factories) == 0:
            msg = "No generator object has attribute '{}'".format(method_name)
            raise AttributeError(msg)
        elif len(factories) == 1:
            return factories[0]

        if weights:
            factory = choices_distribution(factories, weights, length=1)[0]
        else:
            factory = random.choice(factories)
        return factory

    def _map_provider_method(self, method_name):
        """
        Creates a 2-tuple of factories and weights for the given provider method name

        The first element of the tuple contains a list of compatible factories.
        The second element of the tuple contains a list of distribution weights.

        :param method_name: Name of provider method
        :return: 2-tuple (factories, weights)
        """

        # Return cached mapping if it exists for given method
        attr = '_cached_{}_mapping'.format(method_name)
        if hasattr(self, attr):
            return getattr(self, attr)

        # Create mapping if it does not exist
        if self._weights:
            value = [
                (factory, weight)
                for factory, weight in zip(self.factories, self._weights)
                if hasattr(factory, method_name)
            ]
            factories, weights = zip(*value)
            mapping = list(factories), list(weights)
        else:
            value = [
                factory
                for factory in self.factories
                if hasattr(factory, method_name)
            ]
            mapping = value, None

        # Then cache and return results
        setattr(self, attr, mapping)
        return mapping

    @classmethod
    def seed(cls, seed=None):
        """
        Seeds the shared `random.Random` object across all factories

        :param seed: seed value
        """
        Generator.seed(seed)

    def seed_instance(self, seed=None):
        """
        Creates and seeds a new `random.Random` object for each factory

        :param seed: seed value
        """
        for factory in self._factories:
            factory.seed_instance(seed)

    def seed_locale(self, locale, seed=None):
        """
        Creates and seeds a new `random.Random` object for the factory of the specified locale

        :param locale: locale string
        :param seed: seed value
        """
        self._factory_map[locale.replace('-', '_')].seed_instance(seed)

    @property
    def random(self):
        """
        Proxies `random` getter calls

        In single locale mode, this will be proxied to the `random` getter
        of the only internal `Generator` object. Subclasses will have to
        implement desired behavior in multiple locale mode.
        """

        if len(self._factories) == 1:
            return self._factories[0].random
        else:
            msg = 'Proxying `random` getter calls is not implemented in multiple locale mode.'
            raise NotImplementedError(msg)

    @random.setter
    def random(self, value):
        """
        Proxies `random` setter calls

        In single locale mode, this will be proxied to the `random` setter
        of the only internal `Generator` object. Subclasses will have to
        implement desired behavior in multiple locale mode.
        """

        if len(self._factories) == 1:
            self._factories[0].random = value
        else:
            msg = 'Proxying `random` setter calls is not implemented in multiple locale mode.'
            raise NotImplementedError(msg)

    @property
    def locales(self):
        return list(self._locales)

    @property
    def weights(self):
        return self._weights

    @property
    def factories(self):
        return self._factories

    def items(self):
        return self._factory_map.items()



from .. import Provider as InternetProvider


class Provider(InternetProvider):
    safe_email_tlds = ('com', 'net', 'fr', 'fr')
    free_email_domains = (
        'voila.fr',
        'gmail.com',
        'hotmail.fr',
        'yahoo.fr',
        'laposte.net',
        'free.fr',
        'sfr.fr',
        'orange.fr',
        'bouygtel.fr',
        'club-internet.fr',
        'dbmail.com',
        'live.com',
        'ifrance.com',
        'noos.fr',
        'tele2.fr',
        'tiscali.fr',
        'wanadoo.fr')
    tlds = ('com', 'com', 'com', 'net', 'org', 'fr', 'fr', 'fr')
    replacements = (
        ('à', 'a'), ('â', 'a'), ('ä', 'a'),
        ('ç', 'c'),
        ('é', 'e'), ('è', 'e'), ('ê', 'e'), ('ë', 'e'), ('É', 'e'),
        ('ï', 'i'), ('î', 'i'),
        ('ô', 'o'), ('ö', 'o'),
        ('ù', 'u'), ('ü', 'u'),
    )



from .. import Provider as PhoneNumberProvider


class Provider(PhoneNumberProvider):
    formats = (
        # Local calls
        '#### ####',
        '####-####',
        '####.####',  # domain registrars apparently use this
        '########',
        # National dialing
        '0{{area_code}} #### ####',
        '0{{area_code}}-####-####',
        '0{{area_code}}.####.####',
        '0{{area_code}}########',
        # Optional parenthesis
        '(0{{area_code}}) #### ####',
        '(0{{area_code}})-####-####',
        '(0{{area_code}}).####.####',
        '(0{{area_code}})########',
        # International drops the 0
        '+61 {{area_code}} #### ####',
        '+61-{{area_code}}-####-####',
        '+61.{{area_code}}.####.####',
        '+61{{area_code}}########',
        # 04 Mobile telephones (Australia-wide) mostly commonly written 4 - 3 -
        # 3 instead of 2 - 4 - 4
        '04## ### ###',
        '04##-###-###',
        '04##.###.###',
        '+61 4## ### ###',
        '+61-4##-###-###',
        '+61.4##.###.###',
    )

    def area_code(self):
        return self.numerify(self.random_element(
            ['2',
             '3',
             '7',
             '8']))

    def phone_number(self):
        pattern = self.random_element(self.formats)
        return self.numerify(self.generator.parse(pattern))



from collections import OrderedDict

from .. import Provider as ColorProvider

localized = True


class Provider(ColorProvider):
    """Implement color provider for ``ru_RU`` locale."""

    all_colors = OrderedDict((
        ("Античный Белый", "#FAEBD7"),
        ("Аквамарин", "#7FFFD4"),
        ("Лазурный", "#F0FFFF"),
        ("Бежевый", "#F5F5DC"),
        ("Черный", "#000000"),
        ("Синий", "#0000FF"),
        ("Сине-фиолетовый", "#8A2BE2"),
        ("Коричневый", "#A52A2A"),
        ("Шоколадный", "#D2691E"),
        ("Коралловый", "#FF7F50"),
        ("Васильковый", "#6495ED"),
        ("Малиновый", "#DC143C"),
        ("Темно-синий", "#00008B"),
        ("Темно-голубой", "#008B8B"),
        ("Темно-серый", "#A9A9A9"),
        ("Темно-зеленый", "#006400"),
        ("Темный хаки", "#BDB76B"),
        ("Темно-оранжевый", "#FF8C00"),
        ("Темно-красный", "#8B0000"),
        ("Темно-бирюзовый", "#00CED1"),
        ("Темно-фиолетовый", "#9400D3"),
        ("Темно-розовый", "#FF1493"),
        ("Тусклый серый", "#696969"),
        ("Фуксия", "#FF00FF"),
        ("Золотой", "#FFD700"),
        ("Серый", "#808080"),
        ("Зеленый", "#008000"),
        ("Желто-зеленый", "#ADFF2F"),
        ("Ярко-розовый", "#FF69B4"),
        ("Индиго", "#4B0082"),
        ("Слоновая кость", "#FFFFF0"),
        ("Хаки", "#F0E68C"),
        ("Розовато-лавандовый", "#FFF0F5"),
        ("Светло-синий", "#ADD8E6"),
        ("Светло-голубой", "#E0FFFF"),
        ("Светло-серый", "#D3D3D3"),
        ("Светло-зеленый", "#90EE90"),
        ("Светло-розовый", "#FFB6C1"),
        ("Светло-голубой", "#87CEFA"),
        ("Светло-желтый", "#FFFFE0"),
        ("Каштановый", "#800000"),
        ("Оранжевый", "#FFA500"),
        ("Оранжево-красный", "#FF4500"),
        ("Бледно-зеленый", "#98FB98"),
        ("Бледно-Бирюзовый", "#AFEEEE"),
        ("Розовый", "#FFC0CB"),
        ("Сливовый", "#DDA0DD"),
        ("Пурпурный", "#800080"),
        ("Красный", "#FF0000"),
        ("Цвет морской волны", "#2E8B57"),
        ("Серебряный", "#C0C0C0"),
        ("Бирюзовый", "#40E0D0"),
        ("Фиолетовый", "#EE82EE"),
        ("Белый", "#FFFFFF"),
        ("Желтый", "#FFFF00"),
        ("Желто-зеленый", "#9ACD32"),
    ))

    safe_colors = (
        'черный', 'бордовый', 'зеленый', 'оливковый',
        'пурпурный', 'teal', 'lime', 'синий', 'серебряный',
        'серый', 'желтый', 'фуксия', 'белый',
    )



from .. import Provider as LoremProvider


class Provider(LoremProvider):
    """Implement lorem provider for ``ja_JP`` locale."""

    word_connector = ''
    sentence_punctuation = '。'
    word_list = (
        'コミュニティ',
        '隠す',
        '葉',
        '陶器',
        '錯覚',
        'バーゲン',
        'リニア',
        'コーラス',
        '仕上げ',
        '叔父',
        '移動',
        '差別する',
        '極端な',
        '数字',
        'テント',
        '必要',
        '主人',
        '電池',
        'ソース',
        '野球',
        'ストレージ',
        'スキーム',
        '暖かい',
        'ささやき',
        '器官',
        'トリビュート',
        '同行',
        'ジャム',
        'パン',
        '索引',
        'トス',
        '織る',
        'パーセント',
        '拡張',
        '教授',
        'バスケット',
        '創傷',
        'フレーム',
        '明らかにする',
        'フェミニスト',
        '発生する',
        '怒り',
        'ボトル',
        '狐',
        '柔らかい',
        'リフト',
        'バス',
        '雪',
        '画面',
        'パイオニア',
        'マリン',
        'ダイヤモンド',
        '普通の',
        '意図',
        'ヘア',
        '日曜日',
        'プラスチック',
        '衝突',
        '評議会',
        '主婦',
        '保証金',
        '動物',
        '参加する',
        '教会',
        'コミュニケーション',
        '憲法',
        '本質的な',
        '探査',
        '呼ぶ',
        '供給',
        'スペル',
        '再現する',
        '合計',
        'ダッシュ',
        '擁する',
        '知覚',
        'シェービング',
        'コンペ',
        'オークション',
        '細かい',
        'ニュース',
        '癌',
        'トーン',
        'チーズ',
        '反射',
        'ブランチ',
        'コピー',
        '状況',
        'スマッシュ',
        '式',
        '協力',
        '管理する',
        '文言',
        '編組',
        'ジャーナル',
        '腐った',
        '見落とす',
        'ハードウェア',
        'ピック',
        '感謝する',
        '楽しんで',
        '人形',
        '建築',
        '見出し',
        'タワー',
        'ホイール',
        '省略',
        'ログ',
        '助けて',
        '不自然な',
        '出演者',
        '転倒',
        '運',
        '障害',
        'クルー',
        '追放する',
        '月',
        'カレッジ',
        '緩む',
        '分割',
        '欠乏',
        '通行料金',
        '電話',
        '狭い',
        '中央',
        '埋め込む',
        '革新',
        'ブレーキ',
        'コーナー',
        '溝',
        '脊椎',
        'ブラケット',
        '戦略的',
        '尿',
        '血まみれの',
        '尊敬する',
        '催眠術',
        'アクセルペダル',
        '厳しい',
        'サンプル',
        '奨励します',
        '指名',
        'クール',
        'クロス',
        'ヒール',
        '敵対的な',
        '近代化する',
        '部隊',
        '目的',
        '保持する',
        '中世',
        'デッド',
        'ノート',
        'デフォルト',
        '犯罪者',
        'キャビン',
        '副',
        '改善',
        '職人',
        'シュガー',
        '花嫁',
        '倫理',
        '偏差',
        '販売',
        '軸',
        'サラダ',
        '品質',
        '風景',
        '虐待',
        '立派な',
        'ベルベット',
        'ハンマー',
        'キャビネット',
        'トレーナー',
        'リハビリ',
        'サワー',
        '連続',
        '学生',
        '高い',
        '賞賛する',
        '行進',
        'ダニ',
        '証言する',
        '符号',
        'バナー',
        'バケツ',
        'カラム',
        '装置',
        'ヒット',
        '敵',
        'トースト',
        '試してみる',
        '大統領',
        '屋根裏',
        'メニュー',
        '残る',
        'リンク',
        '舗装',
        'インチ',
        '特徴',
        'は',
        '持つ',
        '持っていました',
        'あった',
        '〜',
        'ない',
        '今',
        '今日',
        '持ってる',
        '午前',
        '私',
        '君は',
        '彼',
        '彼女',
        'それ',
        '自体',
        'あなた自身',
        'じぶんの',
        '鉱山',
    )



from .. import Provider as AddressProvider


class Provider(AddressProvider):
    countries = (
        'Afghanistan', 'Alandinseln', 'Albanien', 'Algerien',
        'Amerikanisch-Ozeanien', 'Amerikanisch-Samoa',
        'Amerikanische Jungferninseln', 'Andorra', 'Angola', 'Anguilla',
        'Antarktis', 'Antigua und Barbuda', 'Argentinien', 'Armenien', 'Aruba',
        'Aserbaidschan', 'Australien', 'Bahamas', 'Bahrain', 'Bangladesch',
        'Barbados', 'Belarus', 'Belgien', 'Belize', 'Benin', 'Bermuda',
        'Bhutan', 'Bolivien', 'Bosnien und Herzegowina', 'Botsuana',
        'Bouvetinsel', 'Brasilien', 'Britische Jungferninseln',
        'Britisches Territorium im Indischen Ozean', 'Brunei Darussalam',
        'Bulgarien', 'Burkina Faso', 'Burundi', 'Chile', 'China', 'Cookinseln',
        'Costa Rica', 'Côte d’Ivoire', 'Demokratische Republik Kongo',
        'Demokratische Volksrepublik Korea', 'Deutschland', 'Dominica',
        'Dominikanische Republik', 'Dschibuti', 'Dänemark', 'Ecuador',
        'El Salvador', 'Eritrea', 'Estland', 'Falklandinseln', 'Fidschi',
        'Finnland', 'Frankreich', 'Französisch-Guayana',
        'Französisch-Polynesien', 'Färöer', 'Gabun', 'Gambia', 'Georgien',
        'Ghana', 'Gibraltar', 'Grenada', 'Griechenland', 'Grönland',
        'Guadeloupe', 'Guam', 'Guatemala', 'Guernsey', 'Guinea',
        'Guinea-Bissau', 'Guyana', 'Haiti', 'Heard- und McDonald-Inseln',
        'Honduras', 'Indien', 'Indonesien', 'Irak', 'Iran', 'Irland', 'Island',
        'Isle of Man', 'Israel', 'Italien', 'Jamaika', 'Japan', 'Jemen',
        'Jersey', 'Jordanien', 'Kaimaninseln', 'Kambodscha', 'Kamerun',
        'Kanada', 'Kap Verde', 'Kasachstan', 'Katar', 'Kenia', 'Kirgisistan',
        'Kiribati', 'Kokosinseln', 'Kolumbien', 'Komoren', 'Kongo', 'Kroatien',
        'Kuba', 'Kuwait', 'Laos', 'Lesotho', 'Lettland', 'Libanon', 'Liberia',
        'Libyen', 'Liechtenstein', 'Litauen', 'Luxemburg', 'Madagaskar',
        'Malawi', 'Malaysia', 'Malediven', 'Mali', 'Malta', 'Marokko',
        'Marshallinseln', 'Martinique', 'Mauretanien', 'Mauritius', 'Mayotte',
        'Mazedonien', 'Mexiko', 'Mikronesien', 'Monaco', 'Mongolei',
        'Montenegro', 'Montserrat', 'Mosambik', 'Myanmar', 'Namibia', 'Nauru',
        'Nepal', 'Neukaledonien', 'Neuseeland', 'Nicaragua', 'Niederlande',
        'Niederländische Antillen', 'Niger', 'Nigeria', 'Niue', 'Norfolkinsel',
        'Norwegen', 'Nördliche Marianen', 'Oman', 'Osttimor', 'Pakistan',
        'Palau', 'Palästinensische Gebiete', 'Panama', 'Papua-Neuguinea',
        'Paraguay', 'Peru', 'Philippinen', 'Pitcairn', 'Polen', 'Portugal',
        'Puerto Rico', 'Republik Korea', 'Republik Moldau', 'Ruanda',
        'Rumänien', 'Russische Föderation', 'Réunion', 'Salomonen', 'Sambia',
        'Samoa', 'San Marino', 'Saudi-Arabien', 'Schweden', 'Schweiz',
        'Senegal', 'Serbien', 'Serbien und Montenegro', 'Seychellen',
        'Sierra Leone', 'Simbabwe', 'Singapur', 'Slowakei', 'Slowenien',
        'Somalia', 'Sonderverwaltungszone Hongkong',
        'Sonderverwaltungszone Macao', 'Spanien', 'Sri Lanka',
        'St. Barthélemy', 'St. Helena', 'St. Kitts und Nevis', 'St. Lucia',
        'St. Martin', 'St. Pierre und Miquelon',
        'St. Vincent und die Grenadinen', 'Sudan', 'Suriname',
        'Svalbard und Jan Mayen', 'Swasiland', 'Syrien',
        'São Tomé und Príncipe', 'Südafrika',
        'Südgeorgien und die Südlichen Sandwichinseln', 'Tadschikistan',
        'Taiwan', 'Tansania', 'Thailand', 'Togo', 'Tokelau', 'Tonga',
        'Trinidad und Tobago', 'Tschad', 'Tschechische Republik', 'Tunesien',
        'Turkmenistan', 'Turks- und Caicosinseln', 'Tuvalu', 'Türkei',
        'Uganda', 'Ukraine', 'Ungarn', 'Uruguay', 'Usbekistan', 'Vanuatu',
        'Vatikanstadt', 'Venezuela', 'Vereinigte Arabische Emirate',
        'Vereinigte Staaten', 'Vereinigtes Königreich', 'Vietnam',
        'Wallis und Futuna', 'Weihnachtsinsel', 'Westsahara',
        'Zentralafrikanische Republik', 'Zypern', 'Ägypten',
        'Äquatorialguinea', 'Äthiopien', 'Äußeres Ozeanien', 'Österreich',
    )



from .. import Provider as PersonProvider


class Provider(PersonProvider):
    first_names_female = (
        'Авгия', 'Авигея', 'Авторка', 'Аглая', 'Аглоида', 'Агнешка', 'Адамина', 'Адра', 'Адрианиа', 'Аела', 'Айрен',
        'Аксентия', 'Алания', 'Албина', 'Александрина', 'Алексиа', 'Аленка', 'Алиана', 'Алисия', 'Алтая', 'Амбър',
        'Амория', 'АнаМария', 'Анатолия', 'Ангелка', 'Андика', 'Андриана', 'Анелина', 'анета', 'Анза', 'Анимира',
        'Аница', 'Аномалия', 'Антоалина', 'Антонела', 'Ануша', 'Анхея-мей', 'Аполинария', 'Аралия', 'Аркадия',
        'Арсена', 'Аселина', 'Асифа', 'Астромерия', 'Атина', 'Аурора', 'Багра', 'Балина', 'Бацислава', 'Беатрис',
        'Бела', 'Белисима', 'Беломира', 'Бенелена', 'Берислава', 'Бея', 'Билена', 'Бисера', 'Биянка', 'Благодатка',
        'Благосвета', 'Богдалина', 'Богородка', 'Бодурка', 'Божидара-силвестра', 'Божинела', 'Божурка', 'Бонифация',
        'Борена', 'Бориска', 'Борянка', 'Боца', 'Бригита', 'Бронислава', 'Буна', 'Буча', 'Бързана', 'Ваклина',
        'Валерия', 'Валя', 'Вангелия', 'Ванухи', 'Варта', 'Васенка', 'Василина', 'Васка', 'Вашиля', 'Вежда', 'Велиана',
        'Велинна', 'Велиянка', 'Венда', 'Венеция', 'Венислава', 'Венчислава', 'Верена', 'Верислава', 'Веса',
        'Веселинка', 'Весна', 'Веца', 'Видима', 'Виктория', 'Вилия', 'Вилхема', 'Виолета', 'Виржиния', 'Витомира',
        'Вишка', 'Владилена', 'Владлена', 'Водица', 'Войнка', 'Вула', 'Възкресения', 'Въльо', 'Върбунка', 'Въца',
        'Габи', 'Галена', 'Галина', 'Галя', 'Гануца', 'Гвоздейка', 'Гена', 'Георгелена', 'Георгица', 'Герга',
        'Гердана', 'Гертруда', 'Гиздана', 'Гичка', 'Гордана', 'Гория', 'Гоца', 'Графица', 'Грета', 'Гримяна',
        'Гроздинка', 'Гуна', 'Гъда', 'Гълъбица', 'Гюгра', 'Гюргя', 'Дакота', 'Дамяна', 'Данелина', 'Данимира',
        'Данка', 'Дарданела', 'Дария', 'Дафинка', 'Деа', 'Деви', 'Делиана', 'Деля', 'Демирела', 'Дениандра',
        'Дениславена', 'Денница', 'Десимиляна', 'Десияна', 'Дефлорина', 'Дея', 'Джана', 'Джиневра', 'Джулия',
        'Диана-Мария', 'Дида', 'Дилмана', 'Димитра', 'Димка', 'Динна', 'Добрина', 'Дойка', 'Доменика', 'Доника',
        'Дора-Анна', 'Дорина', 'Доста', 'Доча', 'Драгица', 'Дренка', 'Дуда', 'Душка', 'Дюкяна', 'Евангелина',
        'Евдокия', 'Евридика', 'Едита', 'Ел', 'Елдора', 'Еленица', 'Елеонета', 'Ели', 'Елиз', 'Елина', 'Елиса',
        'Елица', 'Елма', 'Елфида', 'Емануила', 'Емма', 'Еница', 'Ергана', 'Ермиля', 'Естела', 'Ефимена', 'Ефросиния',
        'Жаклин', 'Жанин', 'Жара', 'Жейна', 'Желязка', 'Женимира', 'Жива', 'Живомира', 'Жичка', 'Жорка', 'Жулиана',
        'Заека', 'Занка', 'Зафа', 'Захаринка', 'Звездемира', 'Здравелина', 'Здухостина', 'Зинаида', 'Златея', 'Златка',
        'Златомира', 'Зоичка', 'Зорка', 'Зузичка', 'Ивалена', 'ивамина', 'Иванеса', 'Иваничка', 'Ивелиана', 'Ивинка',
        'Иглика', 'Изидора', 'Илеана', 'Илианна', 'Илинда', 'Илка', 'Инан', 'Инеса', 'Ира', 'Ирин', 'Ирла', 'Исихия',
        'Истилияна', 'Йоана', 'Йоанна', 'Йованка', 'Йоко', 'Йолина', 'Йона', 'Йоника', 'Йорданка', 'Йоханна',
        'Кадифейка', 'Калея', 'Калина', 'Калиса', 'Калуда', 'Камея', 'Кануша', 'Карамелита', 'Карина', 'Касиди',
        'Катастрофа', 'Катинка', 'Каунка', 'Кветослава', 'Керанка', 'Кети', 'Кино', 'Кирка', 'Китчица', 'Клара',
        'Клеуна', 'Клоя', 'Кокимира', 'Комара', 'Константина', 'Корнелия', 'Костадинка', 'Кралина', 'Красидара',
        'Красияна', 'Криси', 'кристабела', 'Кристиана', 'Кристия', 'Кръстанка', 'Ксандриния', 'Кунка', 'Кьнина',
        'Лада', 'Лазура', 'Лалка', 'Лариса', 'Лаца', 'Лека', 'Ленче', 'Летисия', 'Либерта', 'Лидийка', 'Лика', 'Лилия',
        'Лилянка', 'Линда', 'Лия', 'Лозанка', 'Лорена', 'Лоти', 'Луна', 'Лъчезарка', 'Любина', 'Люблина', 'Любослава',
        'Люляна', 'Люсила', 'Лянка', 'Магдалена', 'Мадлен', 'Майя', 'Максимилияна', 'Малена', 'Малтина', 'Манолина',
        'Мара-антоанета', 'Маргит', 'Марен', 'Мари-анри', 'Марийка', 'Маринета', 'Мариотка', 'Мария', 'Мария-елена',
        'Мария-Хуана', 'Марлена', 'Маруся', 'Маса', 'Матка', 'Маша', 'Медиха', 'Мелания', 'Мелъди', 'Меропа',
        'Миглена', 'Мила', 'Милара', 'милдия', 'Милиана', 'Милост', 'Мимоза', 'Минка', 'Миранза', 'Мирена', 'Миропа',
        'Мисла', 'Митошка', 'Михайлена', 'Мишка', 'Младлена', 'Момера', 'Моника', 'Мортадела', 'Мушана', 'Наводненка',
        'Надка', 'Найда', 'Нани', 'Настия', 'Наташа', 'Невена', 'Негрита', 'Неделяна', 'Нейка', 'Нелида', 'Нелла',
        'Неолина', 'Нешка', 'Нигрита', 'Никоела', 'Николина', 'Нионила', 'Нона', 'Норка', 'Нурета', 'Огнена',
        'Октавия', 'Оливера', 'Омана', 'Орлеана', 'Орхидея', 'Павилия', 'Павлина', 'Палвира', 'Паломина', 'Панда',
        'Пантера', 'Парашкевица', 'Парунка', 'Патриотка', 'Паулина', 'Паца', 'Пейолина', 'Пелина', 'Пепелота',
        'Периана', 'перуна', 'Петинка', 'Петрийка', 'Петромира', 'Петрушка', 'Пешка', 'Пламена', 'Плодовитка',
        'Полексина', 'Полин', 'Правда', 'Преса', 'Прина', 'Пролетина', 'Простисвета', 'Пупи', 'Първолетка', 'Рада',
        'Радиа', 'Радимира', 'Радка', 'Радосвета', 'Радостка', 'Раинка', 'Райничка', 'Рамина', 'Ревка', 'Ренгия',
        'Риана', 'Римма', 'Рия', 'Роза', 'Розана', 'Розета', 'Розка', 'Роксана', 'Ромолета', 'Роселина', 'Росислава',
        'Ростислава', 'Ружка', 'Румислава', 'Русалия', 'Руска', 'Сабина', 'Савета', 'Салина', 'Санка', 'Сарая',
        'Сахория', 'Свежа', 'Светла', 'Светломира', 'Свидна', 'Свободка', 'Севда', 'севделина', 'Севета', 'Семенарка',
        'Сергелинка', 'Сибила', 'Сиена', 'Силви', 'Силвия-александра', 'Силяна', 'Симона', 'Синтия', 'Сисоя',
        'Скакалка', 'Славея', 'Славка', 'Сладоледка', 'Смехотерапия', 'Смирна', 'Снежинка', 'Софийка', 'Спасена',
        'Спасияна', 'Спирела', 'Стависара', 'Стаматка', 'Станиела', 'Станимирка', 'Сташа', 'Стелина', 'Стефани',
        'Стеяна', 'Стоимена', 'Столетка', 'Стоянка', 'Сузи', 'Съвестина', 'Сърменка', 'Таисия', 'тамара', 'Таня',
        'Ташимира', 'Теа', 'Телефонка', 'Темира', 'Теодора', 'Теса', 'Тилиана', 'Тиха', 'Тоанета', 'Толиана', 'Тона',
        'Тоницвета', 'Тоска', 'Тошка', 'Трендафила', 'Трифонка', 'Троша', 'Труфана', 'Тръпка', 'Туфка', 'Улиана',
        'Урима', 'Фабияна', 'Фатиме', 'Феня', 'Фикия', 'Филипини', 'Фимка', 'Флавия', 'Флорика', 'Фотинка', 'Фронка',
        'Фуга', 'Хана', 'Харитония', 'Хенриета', 'Хинка', 'Холи', 'Хранислава', 'Хрисанка', 'Христа', 'Христела',
        'Христилияна', 'Христоелена', 'Христя', 'Хубавелка', 'Цанета', 'Царевна', 'Цветана', 'Цветелина', 'Цветилена',
        'Цветлина', 'Цветолилия', 'Цветяна', 'Цеца', 'Цола', 'Цоня', 'Чана', 'Чардафона', 'Чачия', 'Череша',
        'Четвърта', 'Чона', 'Чубрина', 'Шана', 'Шена', 'Шехерезада', 'Шинка', 'Щедра', 'Щериана', 'Щефания', 'Щилянка',
        'Щтилка', 'Ъгленка', 'Ъчка', 'Юлиена', 'Юлия', 'Юнона', 'Юрита', 'Юстианна', 'Ябленка', 'Явора', 'Ягода',
        'Ялислава', 'Яна-Мартина', 'Янина', 'Яниславия', 'Янка', 'Ярка', 'Ясена', 'Ятана',
    )

    first_names_male = (
        'Аблен', 'Август', 'Августиан', 'Августин', 'Авел', 'Авер', 'Аверно', 'Авксентий', 'Аво', 'Аврам', 'Аврели',
        'Аврелий', 'Аврор', 'Агапи', 'Агапий', 'Агатопод', 'Агент', 'Аглай', 'Агнен', 'Агнеш', 'Агоп', 'Агъци',
        'Адалберт', 'Адам', 'Адеан', 'Аделин', 'Адем', 'Адриан', 'Адриян', 'Аерозол', 'Азалия', 'Айдемир', 'Акашия',
        'Аксакусти', 'Аксидан', 'Аксинтия', 'Алберт', 'Албияна', 'Алдин', 'Алевандър', 'Алег', 'Алек', 'Алекзандриян',
        'Беримир', 'Берин', 'Берия', 'Беро', 'Берослав', 'Бетина', 'Бетино', 'Бечо', 'Билян', 'Бинко', 'Биньо',
        'Бисенти', 'Бисер', 'Благо', 'Благовест', 'Благой', 'Благомир', 'Благосвет', 'Блаже', 'Бог', 'Богиня', 'Богой',
        'Боголюб', 'Богомил', 'Богослав', 'Бодромир', 'Божан', 'Божидар', 'Божик', 'Божимир', 'Божин', 'Божинел',
        'Божко', 'Божо', 'Божур', 'Боил', 'Боила', 'Бойко', 'Бойчо', 'Болен', 'Болеслав', 'Боне', 'Бонислав', 'Бонко',
        'Боно', 'Веселин', 'Весислав', 'Весо', 'Веспасиян', 'Ветко', 'Вечко', 'Вигалот', 'Виго', 'Виделин', 'Виден',
        'Видин', 'Видослав', 'Видю', 'Викенти', 'Виктор', 'Вилиан', 'Вилизар', 'Вилизара', 'Вилислав', 'Вилиян',
        'Винету', 'Винко', 'Вино', 'Винсънт', 'Винченцо', 'Виолет', 'Виолин', 'Висарион', 'Виталий', 'Витко', 'Витлян',
        'Витомир', 'Витош', 'Вихрен', 'Вихрони', 'Вихър', 'Вичо', 'Виша', 'Вишетин', 'Вишню', 'Влад', 'Владилен',
        'Владимер', 'Владимир', 'Галентин', 'Галиен', 'Галимир', 'Галиян', 'Гани', 'Ганислав', 'Ганцомир', 'Ганчо',
        'Ганьо', 'Гаро', 'Гатьо', 'Гацо', 'Гвардиана', 'Гелемир', 'Генади', 'ГенадиВалериев', 'Генадий', 'Генислав',
        'Генко', 'Гено', 'Генчо', 'Гео', 'Геодим', 'Геомил', 'Георги', 'Герасим', 'Герган', 'Гергей', 'Гергелюб',
        'Гергин', 'Гердан', 'Герман', 'Геро', 'Герой', 'Герчо', 'Гетислав', 'Гетко', 'Гето', 'Гецо', 'Гечо', 'Гешо',
        'Гивеза', 'Гиздален', 'Гико', 'Гилдрой', 'Делчо', 'Делян', 'Деляна', 'Демир', 'Демян', 'Дениз', 'Деника',
        'Денимир', 'Денис', 'Денислав', 'Дениян', 'Денчо', 'Дердидас', 'десилиан', 'Десимир', 'Десислав', 'Деслав',
        'Деспин', 'Деспинка', 'Деспот', 'Детелин', 'Дечко', 'Дечо', 'Дечю', 'Дешо', 'Деян', 'Джанер', 'Джанко',
        'Джихад', 'Джон-стефан', 'Диаманди', 'Диамантина', 'Диан', 'Диван(надядоДианидядоИван)', 'Дивизие', 'Дивизия',
        'Дивил', 'Дидко', 'Диего', 'Дико', 'Дилян', 'Евстати', 'Евстатий', 'Евстахий', 'Евтим', 'Егор', 'Едвин',
        'Едит', 'Едрю', 'Едуард', 'Еким', 'Ектар', 'Ектор', 'Елвис', 'Елеан', 'Електрон', 'Елемаг', 'Еленко', 'Елиан',
        'Елиас', 'Елиезер', 'Елизабет', 'Елин', 'Елисей', 'Елисия', 'Елко', 'Ельо', 'Ема-Бела', 'Еманоил', 'Емануел',
        'Емануил', 'Емил', 'Емилиан', 'Емилиян', 'Ендо', 'Енчо', 'Еньо', 'Еню', 'Ервин', 'Ередин', 'Еремия', 'Ерик',
        'Ерина', 'Ерол', 'Ерсен', 'Есен', 'Етиен', 'Ефка', 'Заварин', 'Завен', 'Замфир', 'Занго', 'Занко', 'Запрян',
        'Зарко', 'Зафер', 'Зафир', 'Захар', 'Захари', 'Захарин', 'Захо', 'Звездан',  'Звездин', 'Звездислав',
        'Звездиян', 'Звездолет', 'Звездомир', 'Згура', 'Здравелин', 'Здравец', 'Здравко', 'Здравчо', 'Зенгин', 'Зика',
        'Зинко', 'Зинови', 'Златан', 'Злати', 'Златил', 'Златимир', 'Златиян', 'Златко', 'Златогор', 'Златозар',
        'Златомир', 'Златослав', 'Златоцвет', 'Златьо', 'Золтан', 'Илиомар', 'Илич', 'Илия', 'Илиян', 'Илко', 'Илчо',
        'Имилиан', 'Ингемунд', 'Инко', 'Инчо', 'Иполит', 'Ириан', 'Ириней', 'иринеус', 'Ириян', 'Ирко', 'Ирма',
        'Ирник', 'Исак', 'Исидор', 'Искрен', 'Искър', 'Исперих', 'Истан', 'Истатко', 'Истилян', 'Исус', 'Итко',
        'Ихтиандър', 'Ицо', 'Ичо', 'Йено', 'Йеремия', 'Йоан', 'Йоан-Александър', 'Йоан-иво', 'Йован', 'Йовица',
        'Йовко', 'Йово', 'Йовро', 'Йовцо', 'Йовчо', 'Йожи', 'Йоил', 'Йолиян', 'Йолко', 'Карен', 'Карим', 'Карин',
        'Карло', 'Кармен', 'Каролин', 'Карчо', 'Катакомб', 'Каталинка', 'Катерин', 'Кевин', 'Кеворк', 'Кери', 'Кибер',
        'Кимба', 'Кимбо', 'Кимон', 'Кимчо', 'Кин', 'Кинка', 'Кинта', 'Киприслав', 'Киприян', 'Кириен', 'Кирил',
        'Кирчо', 'Киряк', 'Киряки', 'Киряко', 'Кис', 'Кит', 'Кито', 'Китодар', 'Китомир', 'Клим', 'Климент', 'Кнут',
        'Козма', 'Койно', 'Койо', 'Койчо', 'Коко', 'Коле', 'Колчо', 'Кольо', 'Колю', 'Комнин', 'Лалко', 'Лало',
        'Лальо', 'Ламби', 'Ламбо', 'Ламбю', 'Ланселот', 'Ласкал', 'Ласкар', 'Ластър', 'Латин', 'Латко', 'Латьо',
        'Латю', 'ЛЕА-МАРИЯ', 'Леандър', 'Лев', 'Левент', 'Левчо', 'Леко', 'Ленин', 'Ленко', 'Леон', 'Леонид', 'Лесе',
        'Лефтер', 'Лечо', 'Лилко', 'Лило', 'Лилчо', 'Лилян', 'Лимон', 'Липе', 'Лихия', 'Личо', 'Ловчо', 'Лозан',
        'Лозана', 'Лозен', 'Лора-софия', 'Лоранс', 'Лука', 'Лукан', 'Луко', 'Лули', 'Лулчо', 'Лусио', 'Лусия',
        'Маноел', 'Манол', 'Маноло', 'Мантас', 'Мануил', 'Мануш', 'МанчестърЮнайтед', 'Манчо', 'Маньо', 'Маню',
        'Марангони', 'Маргарит', 'Марек', 'Мариан', 'Марий', 'Марин', 'Маринел', 'Маринчо', 'Марио', 'Мариоллита',
        'Маритна', 'Мариян', 'Марк', 'Марк-антоний', 'Марко', 'Маркус', 'Мартен', 'Мартин', 'Мартиниян', 'Маруш',
        'Марчело', 'Маслина', 'Матей', 'Матьо', 'Матю', 'Махно', 'Машо', 'Медиан', 'Мено', 'Мерилин', 'Месак',
        'Метакса', 'Найо', 'Найчо', 'Наке', 'Нако', 'Нанко', 'Нано', 'Нансимир', 'Нанчо', 'Наню', 'Нарцислав', 'Наско',
        'Настимир', 'Настрадин', 'Натанаил', 'Натко', 'Наум', 'Нафисат', 'Нафтали', 'Нацко', 'Нацо', 'Начиян', 'Начко',
        'Начо', 'Невен', 'Невенко', 'Невилиян', 'Невян', 'Негослав', 'Неделин', 'Неделчо', 'Недислав', 'Недко',
        'Недьо', 'Недю', 'Недялко', 'Нейко', 'Нейчо', 'Нелко', 'Нелчо', 'Нене', 'Ненко', 'Ненсислав', 'Ненчо',
        'Неокли', 'Нерес', 'Обретим', 'Ованес', 'Огин', 'Огнемир', 'Огнен', 'Океан', 'Олег', 'Олек', 'Олимпи',
        'Омар', 'Омуртаг', 'Оник', 'Онуфри', 'Ончо', 'Орлин', 'Ортодокси', 'Орфей', 'Орхидей', 'Орце', 'Оскар',
        'Оханес', 'Павел', 'Павелин', 'Павко', 'Павлик', 'Павлин', 'Павлинчо', 'Павломир', 'Паисий', 'Пако', 'Палми',
        'Палмиро', 'Панай', 'Панайот', 'Панде', 'Панделис', 'Пане', 'Панкртийян', 'Пано', 'Панталей', 'Пантелей',
        'Панто', 'Пантю', 'Панчо', 'Паолина', 'Параскев', 'Параход', 'Парашкев', 'Парашкеван', 'Паруш', 'Паско',
        'Паспанахил', 'Пато', 'Патрик', 'Патьо', 'Паулин', 'Паун', 'Пацо', 'Пачо', 'Пейко', 'Пейо', 'Пейодон',
        'Пейтан', 'Пейчин', 'Пейчо', 'Пеко', 'Пелай', 'Пеле', 'Пенко', 'Пенчин', 'Пенчо', 'Пеньо', 'Пеню', 'Пео',
        'Пепино', 'Пепислав', 'Пепо', 'Перикъл', 'Персиана', 'Персиян', 'Перчо', 'Петиконгрес', 'Петкан', 'Петко',
        'Пето', 'Петраки', 'Петрана', 'Петринел', 'Петрозар', 'Петромил', 'Рангел', 'Рангел-любими', 'Рандю', 'Ранчо',
        'Расате', 'Рафаил', 'Рачко', 'Рачо', 'Рашко', 'Рашо', 'Раю', 'Раян', 'Реан', 'Рем', 'Риналдо', 'Рис', 'Ристя',
        'Ричард', 'Ричерд', 'Роберт', 'Роберто', 'Робин', 'Робърт', 'Рогелина', 'Рогена', 'Родан', 'Родион', 'Розалин',
        'Розин', 'Розоцвет', 'Ройо', 'Роксан', 'Ромел', 'Ромелина', 'Ромен', 'Ромео', 'Ромил', 'Ромул', 'Росен',
        'Росенка', 'Росимир', 'Роска', 'Роско', 'Ростиана', 'Ростимир', 'Ростислав', 'Светломир', 'Светлю', 'Светозар',
        'Светослав', 'Себастиан', 'Себахтин', 'Севан', 'Севар', 'Севастин', 'Севдалин', 'Севдан', 'Севелин', 'Северин',
        'Седеф', 'Седефчо', 'Селен', 'Селена', 'Сенко', 'Серафим', 'Сергей', 'Сеслав', 'Сиви', 'Сидер', 'Сидония',
        'Сидор', 'Сиен', 'Силаги', 'Силан', 'Силвестър', 'Силвио', 'Силвиян', 'Силян', 'Симеон', 'Симо', 'Сирман',
        'Сифоня', 'Скорбут', 'Слав', 'Славдо', 'Славе', 'Славейко', 'Славен', 'Слави', 'Славил', 'Теодоси', 'Теодосий',
        'Теодослав', 'Теодостин', 'Теофан', 'Теохар', 'Тервел', 'Тигрони', 'Тило', 'Тильо', 'Тимо', 'Тимон', 'Тимотей',
        'Тимчо', 'Тино', 'Тинчо', 'Тихо', 'Тихол', 'Тихомир', 'Тихон', 'Тишо', 'Тоде', 'Тодомирка', 'Тодораки',
        'Тодорин', 'Тодорина', 'Токимир', 'Толек', 'Толю', 'Тома', 'Томас', 'Томен', 'Томинка', 'Томислав', 'Томо',
        'Тоне', 'Тони', 'Тонимир', 'Тонислав', 'Тонко', 'Тончо', 'Топалко', 'Тополко', 'Тотко', 'Тотьо', 'Тотю',
        'Тоцо', 'Филатей', 'Фили', 'Филидан', 'Филион', 'Филип', 'Филипас', 'Филипопол', 'Филко', 'Филомир', 'Филчо',
        'Фильо', 'Финдо', 'Фиро', 'Фирчо', 'Фичо', 'Флори', 'Флориан', 'Флорин', 'Флоро', 'Фори', 'Фосил', 'Франк',
        'Франц', 'Францислав', 'Фрацил', 'Фреди', 'Фродо', 'Фуго', 'Фуко', 'Фъстък', 'Фьодор', 'Хавтелин', 'Ханко',
        'Хараламби', 'Харалампи', 'Харалан', 'Харбингър', 'Хари', 'Харизан', 'Харитон', 'Хасан', 'Хасатин', 'Хачо',
        'Хвойне', 'Хебър', 'Хектор', 'Хераклит', 'Хернани', 'Хефестион', 'Химинай', 'Хинко', 'Хино', 'Хитко', 'Хороз',
        'Храбрин', 'Храбър', 'Хранимир', 'Хрелко', 'Хрельо', 'Хрисим', 'Хрисимир', 'Хрисо', 'Христалин', 'Христивилин',
        'Христиела', 'Христилиан', 'християн', 'Христо', 'Христо-никола', 'Христодор', 'Христозар', 'Христозорнициан',
        'Христозорницомил', 'Христомил', 'Христомир', 'Христослав', 'Христофор', 'Хрисчо', 'Хрондел', 'Хрусан',
        'Хубав', 'Хубавен', 'Хубан', 'Хубен', 'Цоню', 'Цоцо', 'Цочо', 'Цъки', 'Чавдар', 'Чанкете', 'Чанко', 'Чано',
        'Чаньо', 'Чардафон', 'Чародей', 'Чауш', 'Чачо', 'Чвор', 'Чедомир', 'Ченко', 'Ченю', 'Чепо', 'Черноризец',
        'Черньо', 'Чийо', 'Чико', 'Чило', 'Чонар', 'Чони', 'Чоно', 'Чоню', 'Чочо', 'Чочомир', 'Чубрик', 'Чуде', 'Чудо',
        'Чудомир', 'Чудослав', 'Чук', 'Шабан', 'Шанко', 'Шаноу', 'Шаро', 'Шейна', 'Шеки', 'Шенко', 'Шенол', 'Шибил',
        'Шидер', 'Шинко', 'Шино', 'Шипчан', 'Ширко', 'Шишман', 'Шкодри', 'Шмильо', 'Шмулю', 'Шпилко', 'Шушо', 'Щедрин',
        'Щедю', 'Щеки', 'Щено', 'Щеню', 'Щерион', 'Щериян', 'Щерко', 'Щерьо', 'Щерю', 'Щилиян', 'Щилян', 'Щирян',
        'Щоно', 'Щтърбан', 'Щтъркан', 'Щурк', 'Щърбан', 'Щъркан', 'Ъглен', 'Ълен', 'Ърнест', 'Ъруин', 'Ърчо',
        'Ьобирдар', 'Юги', 'Юлиан', 'Юлий', 'Юлиян', 'Юрдан', 'Юри', 'Юрий', 'Юстин', 'Юстиниан', 'Яблен', 'Явор',
        'Яго', 'Ягодин', 'Язо', 'Яким', 'Яко', 'Якоб', 'Яков', 'Якослав', 'Ян', 'Янадин', 'Янаки', 'Янакин', 'Яначко',
        'Яне', 'Янег', 'Янедин', 'Янек', 'Яни', 'Яниел', 'Яник', 'Янимир', 'Янис', 'Янислав', 'Яничко', 'Янко',
        'Янкул', 'Яно', 'Яномил', 'Янтар', 'Януш', 'Янцислав', 'Янче', 'Янчо', 'Ярно', 'Яромир', 'Ярце', 'Ярчо',
        'Яръм', 'Ярю', 'Ясен', 'Ясер', 'Ястреб', 'Ятан', 'Яцо', 'Ячо', 'Яшар', 'Яшка', 'Яшо', 'Яшон',
    )

    last_names_male = (
        'Симеонов',
        'Данданов',
        'Кърков',
        'Братухчев',
        'Цветков',
        'Иванов',
        'Яназов',
        'Тодоров',
        'Колчев',
        'Келешев',
        'Бърборков',
        'Дришльов',
        'Макаронски',
        'Количков',
        'Принов',
        'Бодуров',
        'Китов',
        'Гьоков',
        'Симеонов',
        'Балахуров',
        'Милачков',
        'ЕвроповКирилов',
        'Площаков',
        'Мангъров',
        'Хвърчилков',
        'Дзезов',
        'Ждраков',
        'Тухчиев',
        'Топков',
        'Яков',
        'Иликьов',
        'Бурханларски',
        'Вражалски',
        'Тутурилов',
        'Бранков',
        'Зенгинов',
        'Фенеров',
        'Кучев',
        'Възвъзов',
        'Кьоров',
        'Джогов',
        'Пъков',
        'Рангелов',
        'Чутурков',
        'Самсонов',
        'Андонов',
        'Бумов',
        'Мочев',
        'Дачев',
        'Муев',
        'Младенов',
        'Тошев',
        'Бедринов',
        'Тумангелов',
        'Канчин',
        'Миленков',
        'Патков',
        'Пондьов',
        'Самоходов',
        'Четрафилски',
        'Смърдански',
        'Клатуров',
        'Вакрилов',
        'Прошков',
        'Пулев',
        'Парашкевов',
        'Манавски',
        'Чуков',
        'Овнарски',
        'Рошльов',
        'Пройкова',
        'Младенова',
        'Кесьов',
        'Римпопов',
        'Златков',
        'Колев',
        'Пикянски',
        'Николов',
        'Цицков',
        'Стойков',
        'Каракашев',
        'Докова',
        'Мераков',
        'Пеева',
        'Педалов',
        'Тъпчилещов',
        'Въртунински',
        'Кодуков',
        'Татьозов',
        'Токов',
        'Юрганчев',
        'Клатикрушев',
        'Монтянов',
        'Бобев',
        'Топчийски',
        'Луланков',
        'Костов',
        'Колипатков',
        'Чукчуков',
        'Катъров',
        'Кобиларов',
        'Лимонадов',
        'Цоцов',
        'Поаков',
        'Недялков',
        'Станишев',
        'Йорданов',
        'Щърбов',
        'Занов',
    )

    last_names_female = (
        'Кокошкова',
        'Градинарова',
        'Куртакова',
        'Чанлиева',
        'Тодорова',
        'Пътечкова',
        'Скринска',
        'Сапунджиева',
        'Вампирска',
        'Васовa',
        'Таралингова',
        'Илиева',
        'Кривошапкова',
        'Чупетловска',
        'Катърова',
        'Бележкова',
        'Мустакова',
        'Пръндачка',
        'Йоткова',
        'Сланинкова',
        'Мангъфова',
        'Шкембова',
        'Пенджакова',
        'Пачаръзка',
        'Куртажова',
        'Плюнкова',
        'Многознаева',
        'Белоконска-Вражалска',
        'Кучкуделова',
        'Крушовска',
        'Пищовколева',
        'Сопаджиева',
        'Точева-Клопова',
        'Габровлиева',
        'Първанова',
        'Певецова',
        'Яркова',
        'Плюцова',
        'Балканска',
    )

    prefixes_female = ('Г-жа', 'Г-ца', 'Др.')
    prefixes_male = ('Г-н', 'Др.')

    formats_female = (
        '{{first_name_female}} {{last_name_female}}',
        '{{prefix_female}} {{first_name_female}} {{last_name_female}}',
    )

    formats_male = (
        '{{first_name_male}} {{last_name_male}}',
        '{{prefix_female}} {{first_name_male}} {{last_name_male}}',
    )

    formats = formats_male + formats_female
    first_names = first_names_male + first_names_female
    last_names = last_names_male + last_names_female



from .. import Provider as InternetProvider


class Provider(InternetProvider):
    # Data taken from
    # https://github.com/fzaninotto/Faker/blob/master/src/Faker/Provider/en_GB/Internet.php

    free_email_domains = (
        'gmail.com',
        'yahoo.com',
        'hotmail.com',
        'gmail.co.uk',
        'yahoo.co.uk',
        'hotmail.co.uk',
    )

    tlds = ('com', 'com', 'com', 'com', 'com', 'com', 'biz', 'info', 'net', 'org', 'co.uk')



import re
import string

from string import ascii_uppercase

from .. import BaseProvider

localized = True
default_locale = 'en_GB'


class Provider(BaseProvider):
    """Implement default bank provider for Faker.

    .. important::
       Bank codes, account numbers, and other ID's generated by this provider
       are only valid in form, i.e. they conform to some standard/format, are
       of the expected lengths, and have valid checksums (where applicable).
       Results generated that turn out to be valid in real life are purely
       coincidental.

    Sources:

    - https://en.wikipedia.org/wiki/International_Bank_Account_Number
    - https://www.theswiftcodes.com/swift-code-checker/
    """

    ALPHA = {c: str(ord(c) % 55) for c in string.ascii_uppercase}
    bban_format = '????#############'
    country_code = 'GB'

    def bank_country(self):
        """Generate the bank provider's ISO 3166-1 alpha-2 country code."""
        return self.country_code

    def bban(self):
        """Generate a Basic Bank Account Number (BBAN)."""
        temp = re.sub(r'\?',
                      lambda x: self.random_element(ascii_uppercase),
                      self.bban_format)
        return self.numerify(temp)

    def iban(self):
        """Generate an International Bank Account Number (IBAN)."""
        bban = self.bban()

        check = bban + self.country_code + '00'
        check = int(''.join(self.ALPHA.get(c, c) for c in check))
        check = 98 - (check % 97)
        check = str(check).zfill(2)

        return self.country_code + check + bban

    def swift8(self, use_dataset=False):
        """Generate an 8-digit SWIFT code.

        This method uses |swift| under the hood with the ``length`` argument set
        to ``8`` and with the ``primary`` argument omitted. All 8-digit SWIFT
        codes already refer to the primary branch/office.

        :sample:
        :sample: use_dataset=True
        """
        return self.swift(length=8, use_dataset=use_dataset)

    def swift11(self, primary=None, use_dataset=False):
        """Generate an 11-digit SWIFT code.

        This method uses |swift| under the hood with the ``length`` argument set
        to ``11``. If ``primary`` is set to ``True``, the SWIFT code will always
        end with ``'XXX'``. All 11-digit SWIFT codes use this convention to
        refer to the primary branch/office.

        :sample:
        :sample: use_dataset=True
        """
        return self.swift(length=11, primary=primary, use_dataset=use_dataset)

    def swift(self, length=None, primary=None, use_dataset=False):
        """Generate a SWIFT code.

        SWIFT codes, reading from left to right, are composed of a 4 alphabet
        character bank code, a 2 alphabet character country code, a 2
        alphanumeric location code, and an optional 3 alphanumeric branch code.
        This means SWIFT codes can only have 8 or 11 characters, so the value of
        ``length`` can only be ``None`` or the integers ``8`` or ``11``. If the
        value is ``None``, then a value of ``8`` or ``11`` will randomly be
        assigned.

        Because all 8-digit SWIFT codes already refer to the primary branch or
        office, the ``primary`` argument only has an effect if the value of
        ``length`` is ``11``. If ``primary`` is ``True`` and ``length`` is
        ``11``, the 11-digit SWIFT codes generated will always end in ``'XXX'``
        to denote that they belong to primary branches/offices.

        For extra authenticity, localized providers may opt to include SWIFT
        bank codes, location codes, and branch codes used in their respective
        locales. If ``use_dataset`` is ``True``, this method will generate SWIFT
        codes based on those locale-specific codes if included. If those codes
        were not included, then it will behave as if ``use_dataset`` were
        ``False``, and in that mode, all those codes will just be randomly
        generated as per the specification.

        :sample:
        :sample: length=8
        :sample: length=8, use_dataset=True
        :sample: length=11
        :sample: length=11, primary=True
        :sample: length=11, use_dataset=True
        :sample: length=11, primary=True, use_dataset=True
        """
        if length is None:
            length = self.random_element((8, 11))
        if length not in (8, 11):
            raise AssertionError('length can only be 8 or 11')

        if use_dataset and hasattr(self, 'swift_bank_codes'):
            bank_code = self.random_element(self.swift_bank_codes)
        else:
            bank_code = self.lexify('????', letters=string.ascii_uppercase)

        if use_dataset and hasattr(self, 'swift_location_codes'):
            location_code = self.random_element(self.swift_location_codes)
        else:
            location_code = self.lexify('??', letters=string.ascii_uppercase + string.digits)

        if length == 8:
            return bank_code + self.country_code + location_code

        if primary:
            branch_code = 'XXX'
        elif use_dataset and hasattr(self, 'swift_branch_codes'):
            branch_code = self.random_element(self.swift_branch_codes)
        else:
            branch_code = self.lexify('???', letters=string.ascii_uppercase + string.digits)

        return bank_code + self.country_code + location_code + branch_code



import re

from faker.utils.decorators import slugify_domain

from .. import Provider as InternetProvider


class Provider(InternetProvider):

    free_email_domains = (
        'hol.gr', 'gmail.com', 'hotmail.gr', 'yahoo.gr', 'googlemail.gr',
        'otenet.gr', 'forthnet.gr',
    )
    tlds = ('com', 'com', 'com', 'net', 'org', 'gr', 'gr', 'gr')

    @slugify_domain
    def user_name(self):
        pattern = self.random_element(self.user_name_formats)
        return latinize(self.bothify(self.generator.parse(pattern)))

    @slugify_domain
    def domain_word(self):
        company = self.generator.format('company')
        company_elements = company.split(' ')
        company = latinize(company_elements.pop(0))
        return company


# ``slugify`` doesn't replace greek glyphs.

def remove_accents(value):
    """
    Remove accents from characters in the given string.
    """
    search = 'ΆΈΉΊΌΎΏάέήίόύώΪϊΐϋΰ'
    replace = 'ΑΕΗΙΟΥΩαεηιουωΙιιυυ'

    def replace_accented_character(match):
        matched = match.group(0)
        if matched in search:
            return replace[search.find(matched)]
        return matched

    return re.sub(r'[{}]+'.format(search), replace_accented_character, value)


def latinize(value):
    """
    Converts (transliterates) greek letters to latin equivalents.
    """
    def replace_double_character(match):
        search = ('Θ Χ Ψ '
                  'θ χ ψ '
                  'ΟΥ ΑΥ ΕΥ '
                  'Ου Αυ Ευ '
                  'ου αυ ευ').split()
        replace = ('TH CH PS '
                   'th ch ps '
                   'OU AU EU '
                   'Ou Au Eu '
                   'ou au eu').split()
        matched = match.group(0)
        if matched in search:
            return replace[search.index(matched)]
        return matched

    search = 'ΑΒΓΔΕΖΗΙΚΛΜΝΞΟΠΡΣΣΤΥΦΩαβγδεζηικλμνξοπρσςτυφω'
    replace = 'AVGDEZIIKLMNXOPRSSTUFOavgdeziiklmnxoprsstyfo'

    def replace_greek_character(match):
        matched = list(match.group(0))
        value = map(lambda l: replace[search.find(l)], matched)
        return ''.join(value)

    return re.sub(r'[{}]+'.format(search),
                  replace_greek_character, re.sub(
        r'([ΘΧΨθχψ]+|ΟΥ|ΑΥ|ΕΥ|Ου|Αυ|Ευ|ου|αυ|ευ)',
        replace_double_character,
        remove_accents(value)))



from ..en_PH import Provider as EnPhBankProvider


class Provider(EnPhBankProvider):
    """Implement bank provider for ``tl_PH`` locale.

    There is no difference from the ``en_PH`` implementation.
    """

    pass



from collections import OrderedDict

from .. import Provider as ColorProvider

localized = True


class Provider(ColorProvider):
    """Implement color provider for ``th_TH`` locale.

    Sources:
    - https://th.wikipedia.org/wiki/รายชื่อสี
    """

    all_colors = OrderedDict((
        ('สีดำ', '#000000'),
        ('สีน้ำเงินเขียว', '#0095B6'),
        ('สีน้ำเงินม่วง', '#8A2BE2'),
        ('สีทองแดง', '#CD7F32'),
        ('สีน้ำตาล', '#964B00'),
        ('สีกาแฟ', '#6F4E37'),
        ('สีทอง', '#FFD700'),
        ('สีเทา', '#808080'),
        ('สีเขียว', '#00FF00'),
        ('สีหยก', '#00A86B'),
        ('สีส้ม', '#FFA500'),
        ('สีส้มแดง', '#FF4500'),
        ('สีออร์คิด', '#DA70D6'),
        ('สีชมพู', '#FFC0CB'),
        ('สีม่วง', '#800080'),
        ('สีแดง', '#FF0000'),
        ('สีเงิน', '#C0C0C0'),
        ('สีขาว', '#FFFFFF'),
        ('สีเหลือง', '#FFFF00'),
    ))

    safe_colors = (
        'สีดำ', 'สีน้ำตาล', 'สีทอง', 'สีเขียว',
        'สีส้ม', 'สีชมพู', 'สีม่วง', 'สีเงิน', 'สีแดง',
        'สีเงิน', 'สีขาว', 'สีเหลือง',
    )



"""Internal module for human-friendly color generation.

.. important::
   End users of this library should not use anything in this module.

Code adapted from:
- https://github.com/davidmerfield/randomColor  (CC0)
- https://github.com/kevinwuhoo/randomcolor-py  (MIT License)

Additional reference from:
- https://en.wikipedia.org/wiki/HSL_and_HSV
"""

import colorsys
import math
import random
import sys

COLOR_MAP = {
    'monochrome': {
        'hue_range': [0, 0],
        'lower_bounds': [
            [0, 0], [100, 0],
        ],
    },
    'red': {
        'hue_range': [-26, 18],
        'lower_bounds': [
            [20, 100], [30, 92], [40, 89],
            [50, 85], [60, 78], [70, 70],
            [80, 60], [90, 55], [100, 50],
        ],
    },
    'orange': {
        'hue_range': [19, 46],
        'lower_bounds': [
            [20, 100], [30, 93], [40, 88], [50, 86],
            [60, 85], [70, 70], [100, 70],
        ],
    },
    'yellow': {
        'hue_range': [47, 62],
        'lower_bounds': [
            [25, 100], [40, 94], [50, 89], [60, 86],
            [70, 84], [80, 82], [90, 80], [100, 75],
        ],
    },
    'green': {
        'hue_range': [63, 178],
        'lower_bounds': [
            [30, 100], [40, 90], [50, 85], [60, 81],
            [70, 74], [80, 64], [90, 50], [100, 40],
        ],
    },
    'blue': {
        'hue_range': [179, 257],
        'lower_bounds': [
            [20, 100], [30, 86], [40, 80],
            [50, 74], [60, 60], [70, 52],
            [80, 44], [90, 39], [100, 35],
        ],
    },
    'purple': {
        'hue_range': [258, 282],
        'lower_bounds': [
            [20, 100], [30, 87], [40, 79],
            [50, 70], [60, 65], [70, 59],
            [80, 52], [90, 45], [100, 42],
        ],
    },
    'pink': {
        'hue_range': [283, 334],
        'lower_bounds': [
            [20, 100], [30, 90], [40, 86], [60, 84],
            [80, 80], [90, 75], [100, 73],
        ],
    },
}


class RandomColor:
    """Implement random color generation in a human-friendly way.

    This helper class encapsulates the internal implementation and logic of the
    :meth:`color() <faker.providers.color.Provider.color>` method.
    """

    def __init__(self, generator=None, seed=None):
        self.colormap = COLOR_MAP

        # Option to specify a seed was not removed so this class
        # can still be tested independently w/o generators
        if generator:
            self.random = generator.random
        else:
            self.seed = seed if seed else random.randint(0, sys.maxsize)
            self.random = random.Random(self.seed)

        for color_name, color_attrs in self.colormap.items():
            lower_bounds = color_attrs['lower_bounds']
            s_min = lower_bounds[0][0]
            s_max = lower_bounds[-1][0]

            b_min = lower_bounds[-1][1]
            b_max = lower_bounds[0][1]

            self.colormap[color_name]['saturation_range'] = [s_min, s_max]
            self.colormap[color_name]['brightness_range'] = [b_min, b_max]

    def generate(self, hue=None, luminosity=None, color_format='hex'):
        """Generate a color.

        Whenever :meth:`color() <faker.providers.color.Provider.color>` is
        called, the arguments used are simply passed into this method, and this
        method handles the rest.
        """
        # First we pick a hue (H)
        h = self.pick_hue(hue)

        # Then use H to determine saturation (S)
        s = self.pick_saturation(h, hue, luminosity)

        # Then use S and H to determine brightness (B).
        b = self.pick_brightness(h, s, luminosity)

        # Then we return the HSB color in the desired format
        return self.set_format([h, s, b], color_format)

    def pick_hue(self, hue):
        """Return a numerical hue value."""
        hue_range = self.get_hue_range(hue)
        hue = self.random_within(hue_range)

        # Instead of storing red as two separate ranges,
        # we group them, using negative numbers
        if hue < 0:
            hue += 360

        return hue

    def pick_saturation(self, hue, hue_name, luminosity):
        """Return a numerical saturation value."""
        if luminosity == 'random':
            return self.random_within([0, 100])

        if hue_name == 'monochrome':
            return 0

        saturation_range = self.get_saturation_range(hue)

        s_min = saturation_range[0]
        s_max = saturation_range[1]

        if luminosity == 'bright':
            s_min = 55
        elif luminosity == 'dark':
            s_min = s_max - 10
        elif luminosity == 'light':
            s_max = 55

        return self.random_within([s_min, s_max])

    def pick_brightness(self, h, s, luminosity):
        """Return a numerical brightness value."""
        b_min = self.get_minimum_brightness(h, s)
        b_max = 100

        if luminosity == 'dark':
            b_max = b_min + 20
        elif luminosity == 'light':
            b_min = (b_max + b_min) / 2
        elif luminosity == 'random':
            b_min = 0
            b_max = 100

        return self.random_within([b_min, b_max])

    def set_format(self, hsv, color_format):
        """Handle conversion of HSV values into desired format."""
        if color_format == 'hsv':
            color = 'hsv({}, {}, {})'.format(*hsv)

        elif color_format == 'hsl':
            hsl = self.hsv_to_hsl(hsv)
            color = 'hsl({}, {}, {})'.format(*hsl)

        elif color_format == 'rgb':
            rgb = self.hsv_to_rgb(hsv)
            color = 'rgb({}, {}, {})'.format(*rgb)

        else:
            rgb = self.hsv_to_rgb(hsv)
            color = '#{:02x}{:02x}{:02x}'.format(*rgb)

        return color

    def get_minimum_brightness(self, h, s):
        """Return the minimum allowed brightness for ``h`` and ``s``."""
        lower_bounds = self.get_color_info(h)['lower_bounds']

        for i in range(len(lower_bounds) - 1):
            s1 = lower_bounds[i][0]
            v1 = lower_bounds[i][1]

            s2 = lower_bounds[i + 1][0]
            v2 = lower_bounds[i + 1][1]

            if s1 <= s <= s2:
                m = (v2 - v1) / (s2 - s1)
                b = v1 - m * s1

                return m * s + b

        return 0

    def get_hue_range(self, color_input):
        """Return the hue range for a given ``color_input``."""
        if isinstance(color_input, (int, float)) and 0 <= color_input <= 360:
            color_input = int(color_input)
            return [color_input, color_input]

        elif isinstance(color_input, str) and color_input in self.colormap:
            return self.colormap[color_input]['hue_range']

        elif color_input is None:
            return [0, 360]

        try:
            v1, v2 = color_input
            v1 = int(v1)
            v2 = int(v2)
        except (ValueError, TypeError):
            msg = 'Hue must be a valid string, numeric type, or a tuple/list of 2 numeric types.'
            raise TypeError(msg)
        else:
            if v2 < v1:
                v1, v2 = v2, v1
            if v1 < 0:
                v1 = 0
            if v2 > 360:
                v2 = 360
            return [v1, v2]

    def get_saturation_range(self, hue):
        """Return the saturation range for a given numerical ``hue`` value."""
        return self.get_color_info(hue)['saturation_range']

    def get_color_info(self, hue):
        """Return the color info for a given numerical ``hue`` value."""
        # Maps red colors to make picking hue easier
        if 334 <= hue <= 360:
            hue -= 360

        for color_name, color in self.colormap.items():
            if color['hue_range'][0] <= hue <= color['hue_range'][1]:
                return self.colormap[color_name]
        else:
            raise ValueError('Value of hue `%s` is invalid.' % hue)

    def random_within(self, r):
        """Return a random integer within the range ``r``."""
        return self.random.randint(int(r[0]), int(r[1]))

    @classmethod
    def hsv_to_rgb(cls, hsv):
        """Convert HSV to RGB.

        This method expects ``hsv`` to be a 3-tuple of H, S, and V values, and
        it will return a 3-tuple of the equivalent R, G, and B values.
        """
        h, s, v = hsv
        h = 1 if h == 0 else h
        h = 359 if h == 360 else h

        h = float(h)/360
        s = float(s)/100
        v = float(v)/100

        rgb = colorsys.hsv_to_rgb(h, s, v)
        return (int(c * 255) for c in rgb)

    @classmethod
    def hsv_to_hsl(cls, hsv):
        """Convert HSV to HSL.

        This method expects ``hsv`` to be a 3-tuple of H, S, and V values, and
        it will return a 3-tuple of the equivalent H, S, and L values.
        """
        h, s, v = hsv

        s = float(s)/100
        v = float(v)/100
        l = 0.5 * v * (2 - s)   # noqa: E741

        if l in [0, 1]:
            s = 0
        else:
            s = v * s / (1 - math.fabs(2 * l - 1))
        return (int(c) for c in [h, s * 100, l * 100])



from .. import Provider as InternetProvider


class Provider(InternetProvider):
    safe_email_tlds = ('com', 'net', 'eu', 'it', 'it', 'it')
    free_email_domains = (
        'libero.it', 'libero.it', 'libero.it',
        'tim.it',
        'tin.it',
        'alice.it',
        'virgilio.it',
        'tiscali.it',
        'fastwebnet.it',
        'vodafone.it',
        'poste.it',
        'gmail.com', 'gmail.com', 'gmail.com',
        'outlook.com',
        'live.com',
        'hotmail.com',
        'hotmail.it',
        'yahoo.com',
        'tele2.it',
    )
    tlds = ('com', 'com', 'com', 'net', 'org', 'eu', 'it', 'it', 'it', 'it')
    replacements = (
        ('à', 'a'), ('é', 'e'), ('è', 'e'),
        ('ì', 'i'), ('ò', 'o'), ('ù', 'u'),
    )



from .. import Provider as LoremProvider


class Provider(LoremProvider):
    """Implement lorem provider for ``hy_AM`` locale.

    Sources:

    - https://www.101languages.net/armenian/armenian-word-list
    """

    word_list = (
        'ես',
        'դու',
        'նա',
        'մենք',
        'դուք',
        'նրանք',
        'այս',
        'այն',
        'այստեղ',
        'այնտեղ',
        'ով',
        'ինչ',
        'որտեղ',
        'ուր',
        'երբ',
        'ինչպես',
        'ոչ',
        'բոլոր',
        'շատ',
        'որոշ',
        'քիչ',
        'այլ',
        'ուրիշ',
        'մեկ',
        'երկու',
        'երեք',
        'չորս',
        'հինգ',
        'մեծ',
        'երկար',
        'լայն',
        'հաստ',
        'ծանր',
        'փոքր',
        'կարճ',
        'նեղ',
        'բարակ',
        'կին',
        'տղամարդ',
        'մարդ',
        'երեխա',
        'կին',
        'ամուսին',
        'մայր',
        'հայր',
        'կենդանի',
        'ձուկ',
        'թռչուն',
        'շուն',
        'ոջիլ',
        'օձ',
        'ճիճու',
        'ծառ',
        'անտառ',
        'փայտ',
        'պտուղ',
        'սերմ',
        'տերև',
        'արմատ',
        'կեղև',
        'ծաղիկ',
        'խոտ',
        'պարան',
        'մաշկ',
        'կաշի',
        'միս',
        'արյուն',
        'ոսկոր',
        'ճարպ',
        'ձու',
        'եղջյուր',
        'պոզ',
        'պոչ',
        'փետուր',
        'մազ',
        'գլուխ',
        'ականջ',
        'աչք',
        'քիթ',
        'բերան',
        'ատամ',
        'լեզու',
        'եղունգ',
        'ոտք',
        'ծունկ',
        'ձեռք',
        'թև',
        'փոր',
        'փորոտիք',
        'աղիք',
        'վիզ',
        'մեջք',
        'կուրծք',
        'սիրտ',
        'լյարդ',
        'խմել',
        'ուտել',
        'կծել',
        'ծծել',
        'թքել',
        'ործկալ',
        'փչել',
        'շնչել',
        'ծիծաղել',
        'տեսնել',
        'լսել',
        'իմանալ',
        'գիտենալ',
        'մտածել',
        'զգալ',
        'վախենալ',
        'քնել',
        'ապրել',
        'մեռնել',
        'սպանել',
        'կռվել',
        'որսալ',
        'խփել',
        'հարվածել',
        'կտրել',
        'բաժանել',
        'խոցել',
        'քերծել',
        'քորել',
        'փորել',
        'լողալ',
        'թռչել',
        'քայլել',
        'գալ',
        'պառկել',
        'նստել',
        'կանգնել',
        'շրջվել',
        'ընկնել',
        'տալ',
        'պահել',
        'բռնել',
        'սեղմել',
        'շփել',
        'լվալ',
        'սրբել',
        'ձգել',
        'քաշել',
        'հրել',
        'նետել',
        'կապել',
        'կարել',
        'հաշվել',
        'ասել',
        'երգել',
        'խաղալ',
        'լողալ',
        'հոսել',
        'սառչել',
        'ուռել',
        'արև',
        'լուսին',
        'աստղ',
        'ջուր',
        'անձրև',
        'գետ',
        'լիճ',
        'ծով',
        'աղ',
        'քար',
        'ավազ',
        'փոշի',
        'հող',
        'ամպ',
        'մառախուղ',
        'մշուշ',
        'երկինք',
        'քամի',
        'ձյուն',
        'սառույց',
        'ծուխ',
        'հուր',
        'կրակ',
        'մոխիր',
        'վառվել',
        'այրվել',
        'ճամփա',
        'ճանապարհ',
        'լեռ',
        'սար',
        'կարմիր',
        'կանաչ',
        'դեղին',
        'սպիտակ',
        'սև',
        'գիշեր',
        'օր',
        'տարի',
        'տաք',
        'ցուրտ',
        'լիքը',
        'նոր',
        'հին',
        'լավ',
        'վատ',
        'փտած',
        'կեղտոտ',
        'ուղիղ',
        'կլոր',
        'սուր',
        'բութ',
        'հարթ',
        'թաց',
        'չոր',
        'ճիշտ',
        'մոտ',
        'հեռու',
        'աջ',
    )



from .. import Provider as AutomotiveProvider


class Provider(AutomotiveProvider):
    """Implement automotive provider for ``pl_PL`` locale.

    Sources:

    - https://en.wikipedia.org/wiki/Vehicle_registration_plates_of_Poland
    """

    license_formats = (
        '?? #####',
        '?? ####?',
        '?? ###??',
        '?? #?###',
        '?? #??##',
        '??? ?###',
        '??? ##??',
        '??? #?##',
        '??? ##?#',
        '??? #??#',
        '??? ??##',
        '??? #####',
        '??? ####?',
        '??? ###??',
    )

    def license_plate_regex_formats(self):
        """Return a regex for matching license plates.

        .. warning::
           This is technically not a method that generates fake data, and it
           should not be part of the public API. User should refrain from using
           this method.
        """
        return [plate.replace('?', '[A-Z]').replace('#', '[0-9]') for plate in self.license_formats]



from .. import Provider as ColorProvider


class Provider(ColorProvider):
    """Implement color provider for ``sk_SK`` locale."""

    safe_colors = (
        'čierna', 'gaštanová', 'zelená', 'námornícka', 'olivová',
        'fialová', 'zelenomodrá', 'limetková', 'modrá', 'strieborná',
        'sivá', 'žltá', 'fuchsiová', 'aquamarinová', 'biela',
    )
